@@ -1,11 +1,11 @@
 from .config import DashConfig
-from .Exceptions import MissingConfigData
+from .Exceptions import MissingConfigData, MissingUserCode
 from requests import post, get
 
 
 class User:
 
-    def __init__(self, secret_code: str):
+    def __init__(self, secret_code: str = None):
         self.code: str = secret_code
 
     @staticmethod
@@ -17,6 +17,8 @@ class User:
 
     @property
     def auth_token(self):
+        if not self.code:
+            raise MissingUserCode
         data = {
             'client_id': self._get_data('CLIENT_ID'),
             'client_secret': self._get_data('CLIENT_SECRET'),
